#!/usr/bin/env python
# -*- coding: utf-8 -*-
from . import utils
from .models import *
import datetime

sd.log_init_config(root_path=sd.config('log_path'))

class Share(object):
	
	@classmethod
	def get_module_config(self, module):
		if not module or module == '':
			sd.log_info('The parameter of module is invaild')
			return None
		sd.log_info(module + ' is sending!')
		user_list = self.get_module_managers(module)
		if not user_list or len(user_list) == 0:
			sd.log_error(
				'[*] Module ' + module + ' is not configed in table "service_config".(or no duty person)')
		_res = utils.build_dic(module=module, user=user_list)
		return _res

	@classmethod
	def get_module_managers(self, module_name):
		service_config = ServiceConfig()
		session = service_config.get_session()
		res = session.query(ServiceConfig).filter(ServiceConfig.service_name == module_name).first()
		if not res:
			return None
		user_list = eval(res.uids)
		sd.log_info('The duty person of module:{} is {}'.format(module_name, user_list))
		service_config.close_session(session)
		return user_list
	
	@classmethod
	def error_log_detail(self, module_name):
		errorlog = ErrorLog()
		session = errorlog.get_session()
		_target_time = datetime.datetime.now() + datetime.timedelta(hours=-1)
		_time = datetime.datetime.strptime("2019-01-01 00:00:00", "%Y-%m-%d %H:%M:%S")
		err_object = session.query(ErrorLog).filter(ErrorLog.module_name == module_name).filter(ErrorLog.create_time >= _target_time).order_by('create_time').all()
		err_count = len(err_object) if err_object else 0
		last_err_content = err_object[-1].content if err_object else ''
		errorlog.close_session(session)
		return err_count, last_err_content
	
	@classmethod
	def get_contact_list(self, user_ids, field):
		supervisor = Supervisor()
		session = supervisor.get_session()
		sd_users = session.query(Supervisor).filter(Supervisor.id.in_(user_ids)).all()
		email_list = []
		phone_list = []
		for user in sd_users:
			if user.email and len(user.email) != 0:
				email_list.append(user.email)
			if user.phone and len(user.phone) != 0:
				phone_list.append(user.phone)
		supervisor.close_session(session)
		if field == 'email':
			sd.log_info('The email of duty person:{} is:{}'.format(user_ids, email_list))
			return email_list
		elif field == 'phone':
			sd.log_info('The phone of duty person:{} is:{}'.format(user_ids, phone_list))
			return phone_list
		return []



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from .send_email import MonitEmialSender
from .send_message import MonitMessageSender
import datetime
from sense_core import config
import sense_core as sd

sd.log_init_config(root_path=sd.config('log_path'))


class Monit_lib(object):
	
	__send_msg_dict = {}
	__send_email_dict = {}
	
	@classmethod
	def send_message(cls, module, title = '日志出现错误', phone_list=None):
		global __send_msg_dict
		_now = datetime.datetime.now()
		monitor_msg = MonitMessageSender()
		if module not in cls.__send_msg_dict:
			cls.__send_msg_dict[module] = _now
			monitor_msg._send_err_message(module, title, phone_list)
		else:
			last_send_time = cls.__send_msg_dict[module]
			if last_send_time < (_now + datetime.timedelta(minutes=-20)):
				cls.__send_msg_dict[module] = _now
				monitor_msg._send_err_message(module, title, phone_list)
			else:
				sd.log_info('The module of {0} has send err message in last 20 minutes'.format(module))
				return None
	
	@classmethod
	def send_email(cls, module, title, receiver_email=None):
		global __send_email_dict
		_now = datetime.datetime.now()
		monitor_email = MonitEmialSender()
		if module not in cls.__send_email_dict:
			cls.__send_email_dict[module] = _now
			monitor_email._send_err_email(module, title, receiver_email)
		else:
			last_send_time = cls.__send_email_dict[module]
			if last_send_time < (_now + datetime.timedelta(minutes=-20)):
				cls.__send_email_dict[module] = _now
				monitor_email._send_err_email(module, title, receiver_email)
			else:
				sd.log_info('The module of {0} has send err email in last 20 minutes'.format(module))
				return None
		
		
		
		
		
		